@@ -16,12 +16,13 @@ class Dotfile(DictParser):
     key_noempty = 'ignoreempty'
     key_trans_r = 'trans_read'
     key_trans_w = 'trans_write'
+    key_template = 'template'
 
     def __init__(self, key, dst, src,
                  actions=[], trans_r=None, trans_w=None,
                  link=LinkTypes.NOLINK, noempty=False,
                  cmpignore=[], upignore=[],
-                 instignore=[]):
+                 instignore=[], template=True):
         """
         constructor
         @key: dotfile key
@@ -35,6 +36,7 @@ class Dotfile(DictParser):
         @upignore: patterns to ignore when updating
         @cmpignore: patterns to ignore when comparing
         @instignore: patterns to ignore when installing
+        @template: template this dotfile
         """
         self.actions = actions
         self.dst = dst
@@ -47,6 +49,7 @@ class Dotfile(DictParser):
         self.upignore = upignore
         self.cmpignore = cmpignore
         self.instignore = instignore
+        self.template = template
 
         if self.link != LinkTypes.NOLINK and \
                 (
@@ -91,6 +94,7 @@ class Dotfile(DictParser):
         value['noempty'] = value.get(cls.key_noempty, False)
         value['trans_r'] = value.get(cls.key_trans_r)
         value['trans_w'] = value.get(cls.key_trans_w)
+        value['template'] = value.get(cls.key_template, True)
         # remove old entries
         value.pop(cls.key_noempty, None)
         value.pop(cls.key_trans_r, None)
@@ -104,8 +108,12 @@ class Dotfile(DictParser):
         return hash(self.dst) ^ hash(self.src) ^ hash(self.key)
 
     def __str__(self):
-        msg = 'key:\"{}\", src:\"{}\", dst:\"{}\", link:\"{}\"'
-        return msg.format(self.key, self.src, self.dst, str(self.link))
+        msg = 'key:\"{}\"'.format(self.key)
+        msg += ', src:\"{}\"'.format(self.src)
+        msg += ', dst:\"{}\"'.format(self.dst)
+        msg += ', link:\"{}\"'.format(str(self.link))
+        msg += ', template:{}'.format(self.template)
+        return msg
 
     def prt(self):
         """extended dotfile to str"""
@@ -114,6 +122,7 @@ class Dotfile(DictParser):
         out += '\n{}src: \"{}\"'.format(indent, self.src)
         out += '\n{}dst: \"{}\"'.format(indent, self.dst)
         out += '\n{}link: \"{}\"'.format(indent, str(self.link))
+        out += '\n{}template: \"{}\"'.format(indent, str(self.template))
 
         out += '\n{}pre-action:'.format(indent)
         some = self.get_pre_actions()
